@@ -27,17 +27,36 @@
 #include <QDir>
 #include <QtWebEngine>
 
+#include <libintl.h>
+
+#include "config.h"
+
 int main(int argc, char *argv[])
 {
     QtWebEngine::initialize();
     QCoreApplication::setAttribute(Qt::AA_ShareOpenGLContexts);
     QGuiApplication *app = new QGuiApplication(argc, (char **)argv);
+    app->setOrganizationName("UBports");
     app->setApplicationName("weather.ubports");
-    app->setApplicationVersion(PROJECT_VERSION);
+    app->setApplicationVersion(projectVersion());
+
+    std::string domainDir = localeDirectory().toStdString();
+
+    textdomain("lomiri-weather-app");
+    bindtextdomain("lomiri-weather-app", domainDir.c_str());
+    bind_textdomain_codeset("lomiri-weather-app", "UTF-8");
 
     qDebug() << "Starting app from main.cpp";
 
     QQuickView *view = new QQuickView();
+
+    // preserve old config location
+    QString dataFolder = QFile::decodeName(qgetenv("XDG_DATA_HOME"));
+    if (dataFolder.isEmpty())
+        dataFolder = QDir::homePath() + QLatin1String("/.local/share");
+    dataFolder += QDir::separator() + QLatin1String("weather.ubports");
+    view->engine()->setOfflineStoragePath(dataFolder);
+
     view->setSource(QUrl("qrc:/lomiri-weather-app.qml"));
     view->setResizeMode(QQuickView::SizeRootObjectToView);
     view->show();
